@@ -1,16 +1,10 @@
 /*
- * Copyright (C) 2003-2009 Sebastian Trueg <trueg@k3b.org>
- * Copyright (C) 2010 Michal Malek <michalm@jabster.pl>
- *
- * This file is part of the K3b project.
- * Copyright (C) 1998-2009 Sebastian Trueg <trueg@k3b.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- * See the file "COPYING" for the exact licensing terms.
- */
+    SPDX-FileCopyrightText: 2003-2009 Sebastian Trueg <trueg@k3b.org>
+    SPDX-FileCopyrightText: 2010 Michal Malek <michalm@jabster.pl>
+    SPDX-FileCopyrightText: 1998-2009 Sebastian Trueg <trueg@k3b.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "k3baudiometainforenamerplugin.h"
 
@@ -56,7 +50,8 @@
 #include <oggflacfile.h>
 
 
-K3B_EXPORT_PLUGIN( k3baudiometainforenamerplugin, K3bAudioMetainfoRenamerPlugin )
+K_PLUGIN_CLASS_WITH_JSON(K3bAudioMetainfoRenamerPlugin , "k3baudiometainforenamerplugin.json")
+
 
 namespace {
     class K3bMimeTypeResolver : public TagLib::FileRef::FileTypeResolver
@@ -219,7 +214,7 @@ void K3bAudioMetainfoRenamerPluginWidget::slotScanClicked()
         rootItem->setExpanded(true);
 
         if( d->renamableItems.isEmpty() )
-            KMessageBox::sorry( this, i18n("No renameable files found.") );
+            KMessageBox::error( this, i18n("No renameable files found.") );
     }
 }
 
@@ -267,7 +262,7 @@ void K3bAudioMetainfoRenamerPluginWidget::scanDir( K3b::DirItem* dir, QTreeWidge
 void K3bAudioMetainfoRenamerPluginWidget::activate()
 {
     if( d->renamableItems.isEmpty() ) {
-        KMessageBox::sorry( this, i18n("Please click the Scan button to search for renameable files.") );
+        KMessageBox::error( this, i18n("Please click the Scan button to search for renameable files.") );
     }
     else {
         for( QList< QPair<K3b::FileItem*, QTreeWidgetItem*> >::iterator it = d->renamableItems.begin();
@@ -344,7 +339,7 @@ QString K3bAudioMetainfoRenamerPluginWidget::createNewName( K3b::FileItem* item
             //
             if( existsOtherItemWithSameName( item, newName + extension ) ) {
                 qDebug() << "(K3bAudioMetainfoRenamerPluginWidget) file with name "
-                         << newName << extension << " already exists" << endl;
+                         << newName << extension << " already exists" << Qt::endl;
                 int i = 1;
                 while( existsOtherItemWithSameName( item, newName + QString( " (%1)").arg(i) + extension ) )
                     i++;
